@@ -3,11 +3,10 @@
 # modify it under the same terms as Perl itself.
 
 package Authen::SASL::CRAM_MD5;
-
+$Authen::SASL::CRAM_MD5::VERSION = '2.1800';
 use strict;
-use vars qw($VERSION);
+use warnings;
 
-$VERSION = "0.99";
 
 sub new {
   shift;
